@@ -81,6 +81,7 @@ public class CSVSerialDataReaderWriter {
 	 * @throws DataInconsitsentException
 	 * @throws DataTypeException
 	 */
+	@SuppressWarnings("resource")
 	public static RecordSet read(String filePath, IDevice device, String recordNameExtend, Integer channelConfigNumber, IDataParser data) throws NotSupportedFileFormatException, IOException, DataInconsitsentException, DataTypeException {
 		String line = GDE.STRING_STAR;
 		BufferedReader reader; // to read the data
@@ -121,19 +122,7 @@ public class CSVSerialDataReaderWriter {
 
 				String recordSetName = (activeChannel.size() + 1) + recordSetNameExtend; //temporary name will be replaced while recordSet creation below
 
-				DataInputStream binReader    = new DataInputStream(new FileInputStream(new File(filePath)));
-				byte[] buffer = new byte[1024];
-				byte[] lineEnding = device.getDataBlockEnding();
-				boolean lineEndingOcurred = false;
-				int chars = binReader.read(buffer);
-				for (int i = 0; i < chars; i++) {
-					if (buffer[i] == lineEnding[0] && i < chars-lineEnding.length-1 && buffer[i+lineEnding.length+1] != '$'
-						&& (lineEnding.length > 1 ? buffer[i+1] == lineEnding[1] : true)) {
-						lineEndingOcurred = true;
-					}
-				}
-				binReader.close();
-				if (!lineEndingOcurred) throw new DevicePropertiesInconsistenceException(Messages.getString(MessageIds.GDE_MSGE0042, new Object[] {chars, filePath}));
+				checkEOL(device, filePath);
 
 				long lastTimeStamp = 0;
 				reader = new BufferedReader(new InputStreamReader(new FileInputStream(filePath), "ISO-8859-1")); //$NON-NLS-1$
@@ -401,6 +390,30 @@ public class CSVSerialDataReaderWriter {
 		return channelRecordSet;
 	}
 
+	/**
+	 * @param device
+	 * @param filePath
+	 * @throws FileNotFoundException
+	 * @throws IOException
+	 * @throws DevicePropertiesInconsistenceException
+	 */
+	private static void checkEOL(IDevice device, String filePath) throws FileNotFoundException, IOException, DevicePropertiesInconsistenceException {
+		DataInputStream binReader    = new DataInputStream(new FileInputStream(new File(filePath)));
+		byte[] buffer = new byte[1024];
+		byte[] lineEnding = device.getDataBlockEnding();
+		char lineLeader = device.getDataBlockLeader().charAt(0);
+		boolean lineEndingOcurred = false;
+		int chars = binReader.read(buffer);
+		for (int i = 0; i < chars; i++) {
+			if (buffer[i] == lineEnding[0] && i < chars-lineEnding.length-1 && buffer[i+lineEnding.length+1] != lineLeader
+				&& (lineEnding.length > 1 ? buffer[i+1] == lineEnding[1] : true)) {
+				lineEndingOcurred = true;
+			}
+		}
+		binReader.close();
+		if (!lineEndingOcurred) throw new DevicePropertiesInconsistenceException(Messages.getString(MessageIds.GDE_MSGE0042, new Object[] {chars, filePath}));
+	}
+
 //	/**
 //	 * write data CVS file
 //	 * @throws Exception
